==> YEAST_1.7.0.tar.gz: YEAST/man/YEASTGO.Rd <==
\name{YEASTGO}
\alias{YEASTGO}
\title{Mappings between probe identifiers and Gene Ontology information}
\description{
  The Gene Ontology Consortium maintains a controlled vocabulary of
  defined terms to describe gene products. YEASTGO maps probe
  identifiers to Gene Ontology information including the ids, evidence
  codes, and ontology categories of the terms for the genes represented by
  the probe ids. 
}
\details{
  Each probe id is mapped to a list containing one (mapped to none or
  one set of GO information) or more (mapped to more than one sets of GO
  information) elements. When a probe id is mapped to at lest one set of
  GO information, each element of the list contains a sub list of three
  elements named "GOID", "Ontology", and "Evidence". The value for element
  "GOID" gives the Gene Ontology identifier the key probe id corresponds
  to. The value for element "Ontology" can be an abbreviation of MF
  (mocular function), BP (biological process), or CC (cellular
  component) for the GO ontology category the GO id belongs to. The
  value for element "Evidence" contains an evidence code indicating what
  kind of evidence is found to support the association of the GO id to
  the gene represented by the key probe id.

  The evidence codes in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to LocusLink ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Yeast Genome:\url{http://www.yeastgenome.org/DownloadContents.shtml}. Built: Yeast Genome data are built at various time  intervals. Sources used were downloaded  Fri Jan  7 14:56:40 2005 


  Gene Ontology:\url{http://www.godatabase.org/dev/database/archive/2004-09-01/go_200409-termdb.xml.gz}. Built: 2004-09-01
  
  Package built Fri Jan  7 16:12:38 2005
}

\examples{
    # Convert to a list
    xx <- as.list(YEASTGO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}

==> YEAST_1.8.1.tar.gz: YEAST/man/YEASTGO.Rd <==
\name{YEASTGO}
\alias{YEASTGO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  YEASTGO is an R environment that provides mappings between
  manufacturer ids and GO ids.
}
\details{
  Each manufacturer id is mapped to a named vector of GO ids. The name
  associated with each GO id corresponds to the evidence code for that
  GO id. Evidence codes currently in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to Entrez Gene ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Yeast Genome: Not available

  Gene Ontology: Not available
  
  Package built Tue May 17 18:17:12 2005
}

\examples{
    # Convert to a list
    xx <- as.list(YEASTGO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}
